summaryrefslogtreecommitdiffstats
path: root/src/commands/edit/PasteEventsCommand.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-02 22:38:52 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-02 22:38:52 +0000
commit458efa7b0c935cbaafa2791021a5f8f7241aa876 (patch)
tree624583f2873febe23770bee3fa94b5c24bd59f4f /src/commands/edit/PasteEventsCommand.cpp
parent747037b72944ae2c02962b7c5c96e0a7f8852e38 (diff)
downloadrosegarden-458efa7b0c935cbaafa2791021a5f8f7241aa876.tar.gz
rosegarden-458efa7b0c935cbaafa2791021a5f8f7241aa876.zip
Initial TQt4 port of Rosegarden
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1230242 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/commands/edit/PasteEventsCommand.cpp')
-rw-r--r--src/commands/edit/PasteEventsCommand.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/commands/edit/PasteEventsCommand.cpp b/src/commands/edit/PasteEventsCommand.cpp
index 2e2e458..9b84ee7 100644
--- a/src/commands/edit/PasteEventsCommand.cpp
+++ b/src/commands/edit/PasteEventsCommand.cpp
@@ -47,14 +47,14 @@ PasteEventsCommand::PasteEventsCommand(Segment &segment,
PasteType pasteType) :
BasicCommand(getGlobalName(), segment, pasteTime,
getEffectiveEndTime(segment, clipboard, pasteTime)),
- m_relayoutEndTime(getEndTime()),
+ m_retqlayoutEndTime(getEndTime()),
m_clipboard(new Clipboard(*clipboard)),
m_pasteType(pasteType),
m_pastedEvents(segment)
{
if (pasteType != OpenAndPaste) {
// paste clef or key -> relayout to end
if (clipboard->isSingleSegment()) {
@@ -62,7 +62,7 @@ PasteEventsCommand::PasteEventsCommand(Segment &segment,
for (Segment::iterator i = s->begin(); i != s->end(); ++i) {
if ((*i)->isa(Clef::EventType) ||
(*i)->isa(Key::EventType)) {
- m_relayoutEndTime = s->getEndTime();
+ m_retqlayoutEndTime = s->getEndTime();
break;
}
}
@@ -76,7 +76,7 @@ PasteEventsCommand::PasteEventsCommand(Segment &segment,
timeT pasteEndTime,
PasteType pasteType) :
BasicCommand(getGlobalName(), segment, pasteTime, pasteEndTime),
- m_relayoutEndTime(getEndTime()),
+ m_retqlayoutEndTime(getEndTime()),
m_clipboard(new Clipboard(*clipboard)),
m_pasteType(pasteType),
m_pastedEvents(segment)
@@ -138,9 +138,9 @@ PasteEventsCommand::getEffectiveEndTime(Segment &segment,
}
timeT
-PasteEventsCommand::getRelayoutEndTime()
+PasteEventsCommand::getRetqlayoutEndTime()
{
- return m_relayoutEndTime;
+ return m_retqlayoutEndTime;
}
bool
@@ -47,14 +47,14 @@ PasteEventsCommand::PasteEventsCommand(Segment &segment,
{
if (pasteType != OpenAndPaste) {
- // paste clef or key -> relayout to end
+ // paste clef or key -> retqlayout to end
if (clipboard->isSingleSegment()) {